@@ -314,7 +314,7 @@ class Nameserver(ApiObject):
     _id_attr: Optional[str] = "hostname"
 
 
-class NameserverService(ListMixin, ApiService):
+class NameserverService(ListMixin, ReplaceMixin, ApiService):
     """Service to nameservers of a domain."""
 
     _path: str = "/domains/{parent_id}/nameservers"
@@ -322,6 +322,14 @@ class NameserverService(ListMixin, ApiService):
 
     _resp_list_attr: str = "nameservers"
 
+    # Additional data for replacing all existing Nameserver objects using the
+    # ReplaceMixin
+    _req_replace_attr: str = "nameservers"
+    _replace_attrs: AttrsTuple = (
+        ("hostname",),  # required
+        ("ipv4", "ipv6")  # optional
+    )
+
 
 class Domain(ApiObject):
 
@@ -452,3 +460,17 @@ class VpsService(GetMixin, DeleteMixin, ListMixin, ApiService):
 
     _resp_list_attr: str = "vpss"
     _resp_get_attr: str = "vps"
+
+
+class Colocation(ApiObject):
+
+    _id_attr: str = "name"
+
+
+class ColocationService(GetMixin, ListMixin, ApiService):
+
+    _path: str = "/colocations"
+    _obj_cls: Optional[Type[ApiObject]] = Colocation
+
+    _resp_list_attr: str = "colocations"
+    _resp_get_attr: str = "colocation"
